@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckReference;
 # ABSTRACT: Git::Hooks plugin for checking references
-$Git::Hooks::CheckReference::VERSION = '2.4.0';
+$Git::Hooks::CheckReference::VERSION = '2.5.0';
 use 5.010;
 use utf8;
 use strict;
@@ -10,7 +10,6 @@ use warnings;
 use Git::Hooks;
 use List::MoreUtils qw/any none/;
 
-my $PKG = __PACKAGE__;
 (my $CFG = __PACKAGE__) =~ s/.*::/githooks./;
 
 sub check_ref {
@@ -22,7 +21,10 @@ sub check_ref {
     if ($old_commit eq $git->undef_commit) {
         if (any  {$ref =~ qr/$_/} $git->get_config($CFG => 'deny') and
             none {$ref =~ qr/$_/} $git->get_config($CFG => 'allow')) {
-            $git->error($PKG, "reference name '$ref' not allowed");
+            $git->fault(<<EOS);
+The reference name '$ref' is not allowed.
+Please, check the $CFG.deny options in your configuration.
+EOS
             return 0;
         }
     }
@@ -65,7 +67,29 @@ Git::Hooks::CheckReference - Git::Hooks plugin for checking references
 
 =head1 VERSION
 
-version 2.4.0
+version 2.5.0
+
+=head1 SYNOPSIS
+
+As a C<Git::Hooks> plugin you don't use this Perl module directly. Instead, you
+may configure it in a Git configuration file like this:
+
+  [githooks]
+    plugin = CheckReference
+    admin = joe molly
+
+  [githooks "checkreference"]
+    deny  = ^refs/heads/
+    allow = ^refs/heads/(?:feature|release|hotfix)/
+
+The first section enables the plugin and defines the users C<joe> and C<molly>
+as administrators, effectivelly exempting them from any restrictions the plugin
+may impose.
+
+The second instance enables C<some> of the options specific to this plugin.
+
+The C<deny> and C<allow> options conspire to only allow the creation of branches
+which names begin with C<feature/>, C<release/>, and C<hotfix/>.
 
 =head1 DESCRIPTION
 
